Data Fields

- SO3_N_MODE_ALL : so3_types.h
- SO3_N_MODE_EVEN : so3_types.h
- SO3_N_MODE_L : so3_types.h
- SO3_N_MODE_MAXIMUM : so3_types.h
- SO3_N_MODE_ODD : so3_types.h
- SO3_N_MODE_SIZE : so3_types.h
- SO3_N_ORDER_NEGATIVE_FIRST : so3_types.h
- SO3_N_ORDER_SIZE : so3_types.h
- SO3_N_ORDER_ZERO_FIRST : so3_types.h
- SO3_SAMPLING_MW : so3_types.h
- SO3_SAMPLING_MW_SS : so3_types.h
- SO3_SAMPLING_SIZE : so3_types.h
- SO3_STORAGE_COMPACT : so3_types.h
- SO3_STORAGE_PADDED : so3_types.h
- SO3_STORAGE_SIZE : so3_types.h